@@ -123,9 +123,9 @@ void BranchContainer::init()
     // Center of whole mainBranches should be the heading
     setCentralContainer(headingContainer);
 
-    // Elastic layout experiments FIXME-3
+    // Elastic layout experiments. v not really used currently  FIXME-3
     v_anim = QPointF(0, 0);
-    v.setParentItem(this);
+    v.setParentItem(this);  // Animation vector for animated layout
     v.setPen(QPen(Qt::red));
     v.setVisible(false);
 
@@ -865,7 +865,8 @@ void BranchContainer::updateUpLink()
     }
 
     // Create/delete bottomline, depends on frame and (List-)Layout
-    if (frameType(true) != FrameContainer::NoFrame ||
+    if (frameType(true)  != FrameContainer::NoFrame ||
+        frameType(false) != FrameContainer::NoFrame ||
         branchesContainerAndOrnamentsVerticalInt ||
         (pbc && pbc->branchesContainerLayoutInt == List)) {
         if (upLink->hasBottomLine())
@@ -975,14 +976,14 @@ void BranchContainer::setBranchesContainerAndOrnamentsVertical(bool b)
     branchesContainerAndOrnamentsVerticalInt = b;
 }
 
-QRectF BranchContainer::headingRect()
+QRectF BranchContainer::headingSceneRect()
 {
     // Returns scene coordinates of bounding rectanble
     return headingContainer->mapToScene(headingContainer->rect())
         .boundingRect();
 }
 
-QRectF BranchContainer::ornamentsRect()
+QRectF BranchContainer::ornamentsSceneRect()
 {
     // Returns scene coordinates of bounding rectanble
     return ornamentsContainer->mapToScene(headingContainer->rect())
@@ -1413,7 +1414,7 @@ void BranchContainer::reposition()
         // on MovingState
         if (pbc) {
             if (pbc->hasFloatingBranchesLayout()) {
-                if (scenePos().x() > pbc->scenePos().x())   // FIXME-2 problematic for rotated elements...
+                if (scenePos().x() > pbc->scenePos().x())   // FIXME-3 Potentially problematic for rotated elements...
                                                             // but OTOH using relative coord
                                                             // often pos.x() == 0
                     orientation = RightOfParent;
