@@ -3,6 +3,8 @@
 
 #include "ui_editxlinkdialog.h"
 
+class XLink;
+
 /*! \brief Dialog to edit or delete XLinks
 
 Using xLinks one can link one branch to any other, just like attaching a rope
@@ -16,14 +18,13 @@ class EditXLinkDialog : public QDialog {
     Q_OBJECT
   public:
     EditXLinkDialog(QWidget *parent = 0);
-    void setLink(Link *);
+    void setLink(XLink *);
     bool useSettingsGlobal();
 
   private slots:
     void widthChanged(int);
     void colorButtonPressed();
     void colorChanged(QColor c);
-    void setColorHeadingButtonPressed();
     void lineStyleChanged(int);
     void beginStyleChanged(int);
     void endStyleChanged(int);
@@ -33,7 +34,7 @@ class EditXLinkDialog : public QDialog {
 
     Ui::EditXLinkDialog ui;
     bool delink;
-    Link *link;
+    XLink *xlink;
 };
 
 #endif // EDITXLINKDIALOG_H
