@@ -11,7 +11,6 @@
 #include "command.h"
 #include "debuginfo.h"
 #include "findresultwidget.h"
-#include "findwidget.h"
 #include "flagrow-master.h"
 #include "headingeditor.h"
 #include "macros.h"
@@ -59,7 +58,7 @@ BranchPropertyEditor *branchPropertyEditor;
 Main *mainWindow;
 ScriptEditor *scriptEditor;
 ScriptOutput *scriptOutput;
-FindWidget *findWidget;
+FindControlsWidget *findControlsWidget;
 FindResultWidget *findResultWidget;
 TaskEditor *taskEditor;
 
@@ -138,9 +137,11 @@ int warningCount = 0;
 int criticalCount = 0;
 int fatalCount = 0;
 
-QString editorFocusStyle =
-    QString(" border-color: #3daee9; border-style:outset; border-width:3px; "
-            "color:black;");
+// Some styles used in various widgets
+QString editorFocusInStyle =
+    QString(" border-color: #3daee9; border-style:outset; border-width:1px; ");// "color:black;");
+QString editorFocusOutStyle = QString("border-width:0px;");
+QString toolBarStyle;
 
 void msgHandler(QtMsgType type, const QMessageLogContext &context,
                 const QString &msg)
@@ -433,9 +434,14 @@ int main(int argc, char *argv[])
             iconTheme = "dark";
         }
     }
+    /*
+    qDebug() << "dark settings: " << settingsDarkTheme
+        << " systemDark=" << systemSeemsDark
+        << " useDark" << usingDarkTheme;
+    */
 
     QPalette palette;
-    if (usingDarkTheme && settingsDarkTheme == "always") {
+    if (usingDarkTheme) {
         qApp->setStyle(QStyleFactory::create("fusion"));
         //qApp->setStyle(QStyleFactory::create("Windows"));
         //qApp->setStyle(QStyleFactory::create("windowsvista"));
@@ -447,7 +453,6 @@ int main(int argc, char *argv[])
         palette.setColor(QPalette::AlternateBase, QColor(53,53,53));
         palette.setColor(QPalette::ToolTipBase, QColor(53,53,53));
         palette.setColor(QPalette::ToolTipText, Qt::white);
-        // Unused: QPalette::PlaceHolderText
         palette.setColor(QPalette::Text, Qt::white);
         palette.setColor(QPalette::Button, QColor(53,53,53));
         palette.setColor(QPalette::ButtonText, Qt::white);
@@ -461,9 +466,49 @@ int main(int argc, char *argv[])
         qApp->setPalette(palette);
 
         vymBlueColor =QColor::fromString("#00aaff");
-    } else
-        vymBlueColor =QColor::fromString("#0000ff");
+    } else {
+        if (systemSeemsDark) {
+            qApp->setStyle(QStyleFactory::create("macOS"));
+            palette.setColor(QPalette::Window, QColor("#ececec"));          // 10
+            palette.setColor(QPalette::WindowText, Qt::black);              //  0
+            palette.setColor(QPalette::Base, QColor("#ffffff"));            //  9
+            palette.setColor(QPalette::AlternateBase, QColor(253,53,53));   // 16
+            palette.setColor(QPalette::ToolTipBase, Qt::white);             // 18
+            palette.setColor(QPalette::ToolTipText, Qt::black);             // 19
+            palette.setColor(QPalette::Text, Qt::black);                    //  6
+            palette.setColor(QPalette::Button, QColor("#ececec"));          //  1
+            palette.setColor(QPalette::ButtonText, Qt::black);              //  8
+            palette.setColor(QPalette::BrightText, Qt::white);              //  7
 
+            /*
+            QPalette::Light	2	Lighter than Button color.
+            QPalette::Midlight	3	Between Button and Light.
+            QPalette::Dark	4	Darker than Button.
+            QPalette::Mid	5	Between Button and Dark.
+            QPalette::Shadow	11	A very dark color. By default, shadow color is Qt::black.
+            */
+            palette.setColor(QPalette::Light, QColor("#ffffff"));           //  2
+            palette.setColor(QPalette::Midlight, QColor("#f5f5f5"));        //  3
+            palette.setColor(QPalette::Dark, QColor("#bfbfbf"));            //  4
+            palette.setColor(QPalette::Mid, QColor("#a9a9a9"));             //  5
+            palette.setColor(QPalette::Shadow, Qt::black);                  // 11
+
+            // Roles of seleced items
+            palette.setColor(QPalette::Highlight, QColor("#a5cdff"));       // 12
+            palette.setColor(QPalette::HighlightedText, Qt::black);         // 13
+
+            // Links
+            /*
+            QPalette::Link	14
+            QPalette::LinkVisited	15
+             */
+            qApp->setPalette(palette);
+        }
+
+        vymBlueColor =QColor::fromString("#0000ff");
+    }
+
+    //  toolBarStyle = "background-color: " + palette.color(QPalette::Button).name() + "; border: None;";   // FIXME-3  Checked buttons no longer visible, introduced for forced bright theme
     vymForegroundColor = palette.color(QPalette::WindowText);
     vymBaseColor = palette.color(QPalette::Base);
 
@@ -531,6 +576,7 @@ int main(int argc, char *argv[])
 
     // Initialize editors
     noteEditor = new NoteEditor(QObject::tr("Note Editor", "Name of editor shown as window title"));
+
     headingEditor = new HeadingEditor(QObject::tr("Heading Editor", "Name of editor shown as window title"));
     branchPropertyEditor = new BranchPropertyEditor();
 
@@ -538,14 +584,27 @@ int main(int argc, char *argv[])
     // overwritten during loading of maps
     lastSessionFiles = settings.value("/mainwindow/sessionFileList", QStringList()).toStringList();
 
-
     // Logfiles (no GUI yet for settings)
     useActionLog = settings.value("/logfile/enabled", false).toBool();
     actionLogPath = settings.value("/logfile/path", QDir::homePath() + "/vym.log").toString();
 
-    // Create MainWindow
+    // Create MainWindow (after creating editors)
     Main m;
 
+    // Add Escape-keys to editors (after creating MainWindow)
+    QAction *a = new QAction("Cancel", noteEditor);
+    a->setShortcut(Qt::Key_Escape);     // Escape in NoteEditor
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    noteEditor->connect(a, SIGNAL(triggered()), mainWindow, SLOT(escapePressed()));
+    noteEditor->addAction(a);
+
+    a = new QAction("Cancel", headingEditor);
+    a->setShortcut(Qt::Key_Escape);     // Escape in HeadingEditor
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    headingEditor->connect(a, SIGNAL(triggered()), mainWindow, SLOT(escapePressed()));
+    headingEditor->addAction(a);
+
+
     // Check for zip tools
     zipToolAvailable = ZipAgent::checkZipTool();
     unzipToolAvailable = ZipAgent::checkUnzipTool();
@@ -647,8 +706,9 @@ int main(int argc, char *argv[])
     // Enable some last minute cleanup
     QObject::connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
 
-    // For benchmarking we may want to quit instead of entering event loop
-    if (options.isActive("quit"))
+    // For benchmarking or if test script is done
+    // we may want to quit instead of entering event loop
+    if (options.isActive("quit") || m.exitAfterScript())
         m.fileExitVYM();
     else
         app.exec();
