@@ -70,10 +70,11 @@ class Main : public QMainWindow {
     void setupAPI();
 
     /*! Helper method to clone actions later in MapEditor */
-    void cloneActionMapEditor(QAction *a, QKeySequence ks);
+    void cloneActionMapEditor(QAction *a);
 
     void setupFileActions();
     void setupEditActions();
+    void setupEditMenu();
     void setupSelectActions();
     void setupFormatActions();
     void setupViewActions();
@@ -117,7 +118,13 @@ class Main : public QMainWindow {
   private slots:
     void editorChanged();
 
+  private:
+    int backgroundZipProcesses;
+    bool closeAfterLastZipProcess;
+
   public slots:
+    void backgroundZipStarted();
+    void backgroundZipFinished();
     bool fileLoad(QString, const File::LoadMode &, const File::FileType &ftype);
     void fileLoad(const File::LoadMode &);
   private slots:
@@ -162,11 +169,23 @@ class Main : public QMainWindow {
     bool fileCloseMap(int i = -1); // Optionally pass number of tab
     void filePrint();
 
+  public:
+    bool exitAfterScript();
+    void setExitAfterScript(bool b);
+
+  private:
+    bool exitAfterScriptInt;
+    QString repeatActionInt;
+
+  public:
+    void setRepeatAction(const QString &script);
+
   public slots:
     bool fileExitVYM();
     void editUndo();
     void editRedo();
     void gotoHistoryStep(int);
+
   private slots:
     void editCopy();
     void editPaste();
@@ -222,7 +241,10 @@ class Main : public QMainWindow {
     void editUnscrollSubtree();
     void editGrowSelectionSize();
     void editShrinkSelectionSize();
+    void editRotateSubtreeCW();
+    void editRotateSubtreeCCW();
     void editResetSelectionSize();
+    void editRepeatLastAction();
     void editAddMapCenter();
     void editAddBranch();
     void editAddBranchBefore();
@@ -236,9 +258,9 @@ class Main : public QMainWindow {
     void editDeleteSelection();
     void editLoadImage();
     void editSaveImage();
-    void popupFollowXLink();
-    void editFollowXLink(QAction *);
     void editEditXLink(QAction *);
+    void popupFollowReference();
+    void followReference(QAction *);
 
   private slots:
     bool initLinkedMapsMenu(VymModel *model, QMenu *menu);
@@ -251,6 +273,8 @@ class Main : public QMainWindow {
     bool initTargetsMenu(VymModel *model, QMenu *menu);
     void editGoToTarget();
     void editMoveToTarget();
+    void editSelectFirstSibling();
+    void editSelectLastSibling();
     void editSelectPrevious();
     void editSelectNext();
     void editSelectNothing();
@@ -321,18 +345,17 @@ class Main : public QMainWindow {
     bool settingsConfluence();
     bool settingsJIRA();
 
-    void windowToggleNoteEditor();
-    void windowToggleTreeEditors();
+    void windowShowNoteEditor();
+    void switchEditors();
     void windowSetTreeEditorsVisibility(bool);
     void windowToggleTaskEditor();
-    void windowToggleSlideEditors();
+    void windowShowSlideEditors();
     void windowSetSlideEditorsVisibility(bool);
     void windowToggleScriptEditor();
     void windowToggleScriptOutput();
     void windowToggleHistory();
     void windowToggleProperty();
     void windowShowHeadingEditor();
-    void windowToggleHeadingEditor();
     void updateHistory(SimpleSettings &);
     void windowToggleAntiAlias();
     bool isAliased();
@@ -355,6 +378,7 @@ class Main : public QMainWindow {
 
     void scriptPrint(const QString &, const QString &color = "");
     QVariant runScript(const QString &);
+    QVariant runScriptWithMacros(const QString &);
     void abortScript(const QJSValue::ErrorType &err, const QString &msg);
     void abortScript(const QString &msg);
     QVariant setScriptResult(const QVariant &r);
@@ -459,6 +483,26 @@ class Main : public QMainWindow {
 
     QMenu *toolbarsMenu;
     QMenu *windowsMenu;
+
+    QMenu *branchAddContextMenu;
+    QMenu *branchGeometryContextMenu;
+    QMenu *branchHierarchyContextMenu;
+    QMenu *branchLinksContextMenu;
+    QMenu *branchRemoveContextMenu;
+    QMenu *branchXLinksContextMenuEdit;
+    QMenu *branchXLinksContextMenuFollow;   // Can also have Urls and VymLinks since 2.9.592
+    QMenu *targetsContextMenu;
+    QMenu *fileLastMapsMenu;
+    QMenu *fileImportMenu;
+    QMenu *fileExportMenu;
+
+    QMenu *fileMenu;
+    QMenu *editMenu;
+    QMenu *selectMenu;
+    QMenu *formatMenu;
+    QMenu *viewMenu;
+    QMenu *connectMenu;
+
     QToolBar *fileToolbar;
     QToolBar *clipboardToolbar;
     QToolBar *editActionsToolbar;
@@ -489,10 +533,14 @@ class Main : public QMainWindow {
     QAction *actionFileExportLast;
     QAction *actionFileExportConfluence;
     QAction *actionUndo;
+    QAction *actionUndoVim;
     QAction *actionRedo;
+    QAction *actionRepeatCommand;
     QAction *actionCopy;
+    QAction *actionCopyVim;
     QAction *actionCut;
     QAction *actionPaste;
+    QAction *actionPasteVim;
     QAction *actionMoveUp;
     QAction *actionMoveDown;
     QAction *actionMoveDownDiagonally;
@@ -501,6 +549,7 @@ class Main : public QMainWindow {
     QAction *actionSortChildren;
     QAction *actionSortBackChildren;
     QAction *actionToggleScroll;
+    QAction *actionUnscrollSubtree;
     QAction *actionExpandAll;
     QAction *actionExpandOneLevel;
     QAction *actionCollapseOneLevel;
@@ -514,6 +563,7 @@ class Main : public QMainWindow {
     QAction *actionLocalURL;
     QAction *actionHeading2URL;
     QAction *actionGetJiraDataSubtree;
+    QAction *actionSetJiraQuery;
     QAction *actionGetConfluencePageDetails;
     QAction *actionGetConfluencePageDetailsRecursively;
     QAction *actionOpenVymLink;
@@ -541,7 +591,7 @@ class Main : public QMainWindow {
     QAction *actionMapInfo;
     QAction *actionHeading;
     QAction *actionDelete;
-    QAction *actionDeleteAlt;
+    QAction *actionCutVim;
 
   public:
     QAction *actionAddMapCenter;
@@ -562,14 +612,23 @@ class Main : public QMainWindow {
     QAction *actionShrinkSelectionSize;
     QAction *actionResetSelectionSize;
 
+    QAction *actionRotateSubtreeCW;
+    QAction *actionRotateSubtreeCCW;
+
     QAction *actionToggleTarget;
     QAction *actionGoToTargetLinkedMap;
     QAction *actionGoToTarget;
     QAction *actionMoveToTarget;
+    QAction *actionSelectFirstSibling;
+    QAction *actionSelectFirstSiblingVim;
+    QAction *actionSelectLastSibling;
+    QAction *actionSelectLastSiblingVim;
     QAction *actionSelectPrevious;
     QAction *actionSelectNext;
     QAction *actionSelectNothing;
     QAction *actionFind;
+    QAction *actionFindVim;
+    QAction *actionFollowReference;
 
     QActionGroup *actionGroupQuickColors;
     QAction *actionFormatQuickColor;
@@ -615,12 +674,8 @@ class Main : public QMainWindow {
     QAction *actionViewToggleNoteEditor;
     QAction *actionViewToggleHeadingEditor;
     QAction *actionViewToggleTaskEditor;
-  
-  public: // Allow VymView class to check visibility  
-    QAction *actionViewToggleTreeEditor;
-    QAction *actionViewToggleSlideEditor;
-
-  private:  
+    QAction *actionViewSwitchEditors;
+    QAction *actionViewShowSlideEditors;
     QAction *actionViewToggleScriptEditor;
     QAction *actionViewToggleScriptOutput;
     QAction *actionViewToggleHistoryWindow;
@@ -631,7 +686,6 @@ class Main : public QMainWindow {
 
     QAction *actionConnectGetConfluenceUser;
     QAction *actionSettingsAutoSelectNewBranch;
-    QAction *actionSettingsAutoSelectText;
     QAction *actionSettingsUseFlagGroups;
     QAction *actionSettingsUseHideExport;
     QAction *actionSettingsToggleAutosave;
