@@ -177,7 +177,7 @@ class MapEditor : public QGraphicsView {
     TreeItem* getItemInDirection(TreeItem *ti, RadarDirection);
     TreeItem* getItemFromGeometry(TreeItem *ti, RadarDirection);
     TreeItem* getItemFromOrgChart(TreeItem *ti, RadarDirection);
-    TreeItem* getItemFromClassicMap(TreeItem *ti, RadarDirection);
+    TreeItem* getItemFromHirarchy(TreeItem *ti, RadarDirection);
 
     TreeItem* getItemDirectAbove(TreeItem *ti);
     TreeItem* getItemDirectBelow( TreeItem *ti);
@@ -195,13 +195,15 @@ class MapEditor : public QGraphicsView {
     void cursorDownToggleSelection();
     void cursorLeft();
     void cursorRight();
-    void cursorFirst();
-    void cursorLast();
     void editHeading(BranchItem *selbi = nullptr);
+    void editHeadingCanceled();
     void editHeadingFinished();
 
   private:
+    void hideLineEdit();
     QLineEdit *lineEdit;
+    QAction *editHeadingCancelAction;
+    QGraphicsProxyWidget *proxyWidget;
 
   private:
     void contextMenuEvent(QContextMenuEvent *e);
@@ -214,6 +216,7 @@ class MapEditor : public QGraphicsView {
     void mouseReleaseEvent(QMouseEvent *);
     void mouseDoubleClickEvent(QMouseEvent *);
     void wheelEvent(QWheelEvent *);
+    void focusInEvent(QFocusEvent *);
     void focusOutEvent(QFocusEvent *);
     void resizeEvent(QResizeEvent *);
 
@@ -269,7 +272,7 @@ class MapEditor : public QGraphicsView {
   public:
     enum SelectionMode {
         AutoSelection,
-        ClassicSelection,
+        HirarchicalSelection,   // legacy selection type (default)
         OrgChartSelection,
         GeometricSelection
     };
