@@ -12,7 +12,7 @@
 extern Main *mainWindow;
 extern SlideEditor *slideEditor;
 
-extern QString editorFocusStyle;
+extern QString editorFocusInStyle;
 
 SlideEditor::SlideEditor(VymModel *m)
 {
@@ -27,7 +27,7 @@ SlideEditor::SlideEditor(VymModel *m)
 
     slideModel->setSelectionModel(view->selectionModel());
 
-    view->setStyleSheet("QTreeView:focus {" + editorFocusStyle + "}");
+    view->setStyleSheet("QTreeView:focus {" + editorFocusInStyle + "}");
 
     // Create ControlWidget
     slideControl = new SlideControlWidget(this);
@@ -58,11 +58,28 @@ SlideEditor::SlideEditor(VymModel *m)
             SIGNAL(selectionChanged(QItemSelection, QItemSelection)), this,
             SLOT(updateSelection(QItemSelection, QItemSelection)));
 
+    QAction *a = new QAction(this);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    a->setShortcut(Qt::CTRL | Qt::Key_D);
+    addAction(a);
+    connect(a, SIGNAL(triggered()), this, SLOT(closeWindow()));
+
+    a = new QAction(this);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    a->setShortcut(Qt::Key_Escape);
+    addAction(a);
+    connect(a, SIGNAL(triggered()), mainWindow, SLOT(escapePressed()));
+
     //    connect (resultsModel, SIGNAL(layoutChanged() ), view, SLOT
     //    (expandAll() ));
 }
 
 void SlideEditor::closeEvent(QCloseEvent *event)
+{
+    closeWindow();
+}
+
+void SlideEditor::closeWindow()
 {
     mainWindow->windowSetSlideEditorsVisibility(false);
 }
