@@ -30,6 +30,10 @@ extern QColor vymForegroundColor;
 extern QColor vymBaseColor;
 extern QAction *actionViewToggleNoteEditor;
 
+extern QString editorFocusInStyle;
+extern QString editorFocusOutStyle;
+extern QString toolBarStyle;
+
 extern QString vymName;
 
 extern Switchboard switchboard;
@@ -57,6 +61,14 @@ TextEditor::TextEditor(const QString eName)   // FEATURE #137 insert images with
     connect(editor, SIGNAL(currentCharFormatChanged(const QTextCharFormat &)), this,
             SLOT(formatChanged(const QTextCharFormat &)));
 
+
+    QAction *a = new QAction("Close window", this);
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    a->setShortcut(Qt::CTRL | Qt::Key_D);
+    connect(a, SIGNAL(triggered()), this, SLOT(closeWindow()));
+    //fileMenu->addAction(a);
+    editor->addAction(a);
+
     // Load settings
     init (eName);
     setWindowIcon(QPixmap(":/vym-editor.png"));
@@ -318,15 +330,15 @@ void TextEditor::setFocus() { editor->setFocus(); }
 void TextEditor::setupFileActions()
 {
     QToolBar *tb = addToolBar(tr("Note Actions"));
+    tb->setStyleSheet(toolBarStyle);
     tb->setObjectName("noteEditorFileActions");
     QMenu *fileMenu = menuBar()->addMenu(tr("&Note", "Menubar"));
 
-    QString tag = tr("Texteditor", "Shortcuts");
+    QString tag = tr("File actions", "TextEditor shortcut groups");
     QAction *a;
     a = new QAction(QPixmap(QString(":/document-open-%1").arg(iconTheme)), tr("&Import..."), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_O);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textLoad", shortcutScope, a, tag);
+    switchboard.addAction(a, "textLoad", Qt::CTRL | Qt::Key_O, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textLoad()));
     tb->addAction(a);
     fileMenu->addAction(a);
@@ -334,9 +346,8 @@ void TextEditor::setupFileActions()
 
     fileMenu->addSeparator();
     a = new QAction(QPixmap(QString(":/document-export-%1").arg(iconTheme)), tr("&Export..."), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_S);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textSave", shortcutScope, a, tag);
+    switchboard.addAction(a, "textSave", Qt::CTRL | Qt::Key_S, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textExport()));
     tb->addAction(a);
     fileMenu->addAction(a);
@@ -345,7 +356,7 @@ void TextEditor::setupFileActions()
     actionFileExport = a;
 
     a = new QAction(tr("Export &As...(ASCII)"), this);
-    switchboard.addSwitch("textExportAsASCII", shortcutScope, a, tag);
+    switchboard.addAction(a, "textExportAsASCII", shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textExportText()));
     fileMenu->addAction(a);
     addAction(a);
@@ -354,8 +365,7 @@ void TextEditor::setupFileActions()
 
     fileMenu->addSeparator();
     a = new QAction(QPixmap(QString(":/document-print-%1.svg").arg(iconTheme)), tr("&Print..."), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_P);
-    switchboard.addSwitch("textPrint", shortcutScope, a, tag);
+    switchboard.addAction(a, "textPrint", Qt::CTRL | Qt::Key_P, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textPrint()));
     tb->addAction(a);
     fileMenu->addAction(a);
@@ -372,17 +382,17 @@ void TextEditor::setupFileActions()
 
 void TextEditor::setupEditActions()
 {
-    QString tag = tr("Texteditor", "Shortcuts");
+    QString tag = tr("Edit actions", "TextEditor shortcut groups");
     QToolBar *editToolBar = addToolBar(tr("Edit Actions"));
+    editToolBar->setStyleSheet(toolBarStyle);
     editToolBar->setObjectName("noteEditorEditActions");
     editToolBar->hide();
     QMenu *editMenu = menuBar()->addMenu(tr("Edi&t"));
 
     QAction *a;
     a = new QAction(QPixmap(":/undo.png"), tr("&Undo"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_Z);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textUndo", shortcutScope, a, tag);
+    switchboard.addAction(a, "textUndo", Qt::CTRL | Qt::Key_Z, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), editor, SLOT(undo()));
     editMenu->addAction(a);
     editToolBar->addAction(a);
@@ -390,9 +400,8 @@ void TextEditor::setupEditActions()
     actionEditUndo = a;
 
     a = new QAction(QPixmap(":/redo.png"), tr("&Redo"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_Y);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textRedo", shortcutScope, a, tag);
+    switchboard.addAction(a, "textRedo", Qt::CTRL | Qt::Key_Y, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), editor, SLOT(redo()));
     editMenu->addAction(a);
     editToolBar->addAction(a);
@@ -402,8 +411,7 @@ void TextEditor::setupEditActions()
     editMenu->addSeparator();
     a = new QAction(QPixmap(), tr("Select and copy &all"), this);
     a->setShortcutContext(Qt::WidgetShortcut);
-    a->setShortcut(Qt::CTRL | Qt::Key_A);
-    switchboard.addSwitch("textCopyAll", shortcutScope, a, tag);
+    switchboard.addAction(a, "textCopyAll", Qt::CTRL | Qt::Key_A, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(editCopyAll()));
     editMenu->addAction(a);
     filledEditorActions << a;
@@ -411,9 +419,8 @@ void TextEditor::setupEditActions()
 
     editMenu->addSeparator();
     a = new QAction(QPixmap(QString(":/edit-copy-%1.svg").arg(iconTheme)), tr("&Copy", "Edit menu"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_C);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textCopy", shortcutScope, a, tag);
+    switchboard.addAction(a, "textCopy", Qt::CTRL | Qt::Key_C, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), editor, SLOT(copy()));
     editMenu->addAction(a);
     editToolBar->addAction(a);
@@ -421,9 +428,8 @@ void TextEditor::setupEditActions()
     actionEditCopy = a;
 
     a = new QAction(QPixmap(QString(":/edit-cut-%1.svg").arg(iconTheme)), tr("Cu&t", "Edit menu"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_X);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textCut", shortcutScope, a, tag);
+    switchboard.addAction(a, "textCut", Qt::CTRL | Qt::Key_X, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), editor, SLOT(cut()));
     editMenu->addAction(a);
     editToolBar->addAction(a);
@@ -431,9 +437,8 @@ void TextEditor::setupEditActions()
     actionEditCut = a;
 
     a = new QAction(QPixmap(QString(":/edit-paste-%1.svg").arg(iconTheme)), tr("&Paste", "Edit menu"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_V);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textPaste", shortcutScope, a, tag);
+    switchboard.addAction(a, "textPaste", Qt::CTRL | Qt::Key_V, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), editor, SLOT(paste()));
     editMenu->addAction(a);
     editToolBar->addAction(a);
@@ -451,20 +456,20 @@ void TextEditor::setupEditActions()
 
 void TextEditor::setupFormatActions()
 {
-    QString tag = tr("Texteditor", "Shortcuts");
+    QString tag = tr("Format actions", "TextEditor shortcut groups");
     fontHintsToolBar =
         addToolBar(tr("Font hints", "toolbar in texteditor"));
+    fontHintsToolBar->setStyleSheet(toolBarStyle);
     fontHintsToolBar->setObjectName("noteEditorFontToolBar");
     QMenu *formatMenu = menuBar()->addMenu(tr("F&ormat"));
 
     QAction *a;
 
     a = new QAction(QPixmap(":/formatfixedfont.png"), tr("&Font hint"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_H);
     a->setCheckable(true);
     a->setChecked(
         settings.value("/noteeditor/fonts/useFixedByDefault", false).toBool());
-    switchboard.addSwitch("textToggleFonthint", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleFonthint", Qt::CTRL | Qt::Key_H, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(toggleFonthint()));
     formatMenu->addAction(a);
     fontHintsToolBar->addAction(a);
@@ -473,10 +478,8 @@ void TextEditor::setupFormatActions()
 
     // Original icon: ./share/icons/oxygen/22x22/actions/format-text-color.png
     a = new QAction(QPixmap(":/formatrichtext.svg"), tr("&Richtext"), this);
-    //  a->setShortcut(Qt::CTRL | Qt::Key_R);
-    //  a->setShortcutContext (Qt::WidgetShortcut);
     a->setCheckable(true);
-    switchboard.addSwitch("textToggleRichText", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleRichText", shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(toggleRichText()));
     formatMenu->addAction(a);
     fontHintsToolBar->addAction(a);
@@ -486,6 +489,7 @@ void TextEditor::setupFormatActions()
     addToolBarBreak();
 
     fontToolBar = addToolBar(tr("Fonts", "toolbar in texteditor"));
+    fontToolBar->setStyleSheet(toolBarStyle);
     fontToolBar->setObjectName("noteEditorFontToolBar");
 
     comboFont = new QComboBox;
@@ -512,6 +516,7 @@ void TextEditor::setupFormatActions()
     addToolBarBreak();
 
     formatToolBar = addToolBar(tr("Format", "toolbar in texteditor"));
+    formatToolBar->setStyleSheet(toolBarStyle);
     formatToolBar->setObjectName("noteEditorFormatToolBar");
 
     //QPixmap pix(16, 16);
@@ -534,9 +539,8 @@ void TextEditor::setupFormatActions()
     actionTextBGColor = a;
 
     a = new QAction(QPixmap(QString(":/format-text-bold-%1.svg").arg(iconTheme)), tr("&Bold"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_B);
 //    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textToggleBold", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleBold", Qt::CTRL | Qt::Key_B, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textBold()));
     formatToolBar->addAction(a);
     formatMenu->addAction(a);
@@ -545,9 +549,8 @@ void TextEditor::setupFormatActions()
     actionTextBold = a;
 
     a = new QAction(QPixmap(QString(":/format-text-italic-%1.svg").arg(iconTheme)), tr("&Italic"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_I);
 //    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textToggleItalic", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleItalic", Qt::CTRL | Qt::Key_I, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textItalic()));
     formatToolBar->addAction(a);
     formatMenu->addAction(a);
@@ -556,9 +559,8 @@ void TextEditor::setupFormatActions()
     actionTextItalic = a;
 
     a = new QAction(QPixmap(QString(":/text-format-underline-%1.svg").arg(iconTheme)), tr("&Underline"), this);
-    a->setShortcut(Qt::CTRL | Qt::Key_U);
 //    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    switchboard.addSwitch("textToggleUnderline", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleUnderline", Qt::CTRL | Qt::Key_U, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textUnderline()));
     formatToolBar->addAction(a);
     formatMenu->addAction(a);
@@ -571,23 +573,19 @@ void TextEditor::setupFormatActions()
     QActionGroup *actGrp2 = new QActionGroup(this);
     actGrp2->setExclusive(true);
     a = new QAction(QPixmap(QString(":/text-format-subscript-%1.svg").arg(iconTheme)), tr("Subs&cript"), actGrp2);
-    a->setShortcut(Qt::CTRL | Qt::SHIFT | Qt::Key_B);
-//    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setCheckable(true);
     formatToolBar->addAction(a);
     formatMenu->addAction(a);
-    switchboard.addSwitch("textToggleSub", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleSub", Qt::CTRL | Qt::SHIFT | Qt::Key_B, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textVAlign()));
     filledEditorRichTextActions << a;
     actionAlignSubScript = a;
 
     a = new QAction(QPixmap(QString(":/text-format-superscript-%1.svg").arg(iconTheme)), tr("Su&perscript"), actGrp2);
-    a->setShortcut(Qt::CTRL | Qt::SHIFT | Qt::Key_P);
-//    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     a->setCheckable(true);
     formatToolBar->addAction(a);
     formatMenu->addAction(a);
-    switchboard.addSwitch("textToggleSuper", shortcutScope, a, tag);
+    switchboard.addAction(a, "textToggleSuper", Qt::CTRL | Qt::SHIFT | Qt::Key_P, shortcutScope, tag);
     connect(a, SIGNAL(triggered()), this, SLOT(textVAlign()));
     filledEditorRichTextActions << a;
     actionAlignSuperScript = a;
@@ -709,14 +707,22 @@ void TextEditor::textLoad()
 void TextEditor::closeEvent(QCloseEvent *ce)
 {
     ce->accept(); // TextEditor can be reopened with show()
-    hide();
-    emit windowClosed();
-    return;
+    closeWindow();
 }
 
 bool TextEditor::eventFilter(QObject *obj, QEvent *ev)
 {
     if (obj == editor) {
+        // qDebug() << "TE::eventFilter   ev=" << ev;
+        if (ev->type() == QEvent::FocusIn) {
+            //editor->setFrameStyle(QFrame::Box);
+            editor->setStyleSheet("QTextEdit {" + editorFocusInStyle + "}");
+        }
+        if (ev->type() == QEvent::FocusOut) {
+            editor->setFrameStyle(QFrame::NoFrame);
+            editor->setStyleSheet("QTextEdit {" + editorFocusOutStyle + "}");
+
+        }
         if (ev->type() == QEvent::KeyPress) {
             QKeyEvent *keyEvent = static_cast<QKeyEvent *>(ev);
             if (keyEvent == QKeySequence::Paste) {
@@ -839,6 +845,13 @@ void TextEditor::clear()
     blockChangedSignal = blockChangedOrg;
 }
 
+void TextEditor::closeWindow()
+{
+    parentWidget()->hide();
+    emit windowClosed();
+    return;
+}
+
 void TextEditor::deleteAll()
 {
     editor->clear();
