@@ -172,16 +172,17 @@ class VymModel : public TreeModel {
   public:
     /*! \brief Save the map to file */
     bool saveMap(const File::SaveMode &);
+    bool isLoading();
     bool isSaving();
+    bool isBusy();
 
   private slots:
     void zipFinished ();
 
   private:
-
-
     ZipAgent *zipAgent;
     bool isSavingInt;
+    bool isLoadingInt;
 
   public:
     ImageItem* loadImage(
@@ -262,14 +263,16 @@ class VymModel : public TreeModel {
     bool isRedoAvailable(); //!< True, if redo is available
     QString lastRedoSelection();
     QString lastRedoCommand();
-    QVariant repeatLastCommand(); //!< Repeat last command on current selection
+    QString lastRedoComment();
+    QString lastUndoCommand();
+    QString lastUndoComment();
 
-    void undo();               //!< Undo last action
-    bool isUndoAvailable();    //!< True, if undo is available
-    void gotoHistoryStep(int); //!< Goto a specifig step in history
+    void undo();                    //!< Undo last action
+    bool isUndoAvailable();         //!< True, if undo is available
+    void gotoHistoryStep(int);      //!< Goto a specifig step in history
 
-    QString getHistoryPath(); //!< Path to directory containing the history
-    void resetHistory();      //!< Initialize history
+    QString getHistoryPath();       //!< Path to directory containing the history
+    void resetHistory();            //!< Initialize history
 
     QString setAttributeVar(AttributeItem*, QString varName ="b");  //!< Returns command to set AttributeItem in scripts for undo/redo
     QString setBranchVar(BranchItem*, QString varName ="b");  //!< Returns command to set BranchItem in scripts for undo/redo
@@ -308,6 +311,7 @@ class VymModel : public TreeModel {
     /*! Put several states into one Script for a single undo step */
     void saveStateBeginScript(const QString &comment);
     void saveStateEndScript();
+    void saveStateCancelScript();
 
     ////////////////////////////////////////////
     // unsorted so far
@@ -392,6 +396,7 @@ class VymModel : public TreeModel {
     void setRotationAutoDesign(const bool &, BranchItem *bi = nullptr);
     void setRotationHeading(const int &, BranchItem *bi = nullptr);
     void setRotationSubtree(const int &, BranchItem *bi = nullptr);
+    void rotateSubtree(qreal a);
     void setScaleAutoDesign(const bool &, BranchItem *bi = nullptr);
     void setScaleHeading(const qreal &, const bool relative = false, BranchItem *bi = nullptr);
     qreal getScaleHeading();
@@ -595,7 +600,6 @@ class VymModel : public TreeModel {
     void deleteVymLink();                // delete link to another map
     QString getVymLink();                // return path to map
     QStringList getVymLinks();           // return paths in subtree
-    void followXLink(int);
     void editXLink();
     void setXLinkColor(const QString &, XLink *xl = nullptr);
     void setXLinkStyle(const QString &, XLink *xl = nullptr);
