@@ -481,11 +481,6 @@ void VymModelWrapper::removeXLink(XLinkWrapper *xlw)
     modelInt->deleteXLink(xlw->xlink());
 }
 
-QVariant VymModelWrapper::repeatLastCommand()
-{
-    return modelInt->repeatLastCommand();
-}
-
 bool VymModelWrapper::saveSelection(const QString &filename)
 {
     QString filename_org = modelInt->getFilePath(); // Restore filename later
@@ -541,6 +536,17 @@ BranchWrapper* VymModelWrapper::selectedBranch()
         return nullptr; // caught by QJSEngine
 }
 
+QList <BranchWrapper*> VymModelWrapper::selectedBranches()
+{
+    QList <BranchItem*> selbis = modelInt->getSelectedBranches();
+
+    QList <BranchWrapper*> rlist;
+    foreach (BranchItem *selbi, selbis)
+        rlist << selbi->branchWrapper();
+
+    return rlist;
+}
+
 XLinkWrapper* VymModelWrapper::selectedXLink()
 {
     XLinkItem *xli = modelInt->getSelectedXLinkItem();
