@@ -11,6 +11,8 @@
 extern Main *mainWindow;
 extern Settings settings;
 
+extern QString editorFocusInStyle;
+
 VymView::VymView(VymModel *m)
 {
     model = m;
@@ -30,12 +32,19 @@ VymView::VymView(VymModel *m)
     TreeDelegate *delegate = new TreeDelegate(this);
     treeEditor->setItemDelegate(delegate);
 
+    // Add Escape-keys to editors
+    QAction *a = new QAction("Cancel", treeEditor);
+    a->setShortcut(Qt::Key_Escape);     // Escape in NoteEditor
+    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
+    treeEditor->connect(a, SIGNAL(triggered()), mainWindow, SLOT(escapePressed()));
+    treeEditor->addAction(a);
+
     DockEditor *de;
     de = new DockEditor(tr("Tree Editor", "Title of dockable editor widget"),
                         this, model);
     de->setWidget(treeEditor);
     de->setAllowedAreas(Qt::AllDockWidgetAreas);
-    de->setVisible(mainWindow->actionViewToggleTreeEditor->isChecked());
+    de->setVisible(settings.value("/mainwindow/view/showTreeEditors", true).toBool());
     addDockWidget(Qt::LeftDockWidgetArea, de);
     treeEditorDE = de;
 
@@ -52,7 +61,7 @@ VymView::VymView(VymModel *m)
                         this, model);
     de->setWidget(slideEditor);
     de->setAllowedAreas(Qt::AllDockWidgetAreas);
-    de->setVisible(mainWindow->actionViewToggleSlideEditor->isChecked());
+    de->setVisible(settings.value("/mainwindow/view/showSlideEditors", false).toBool());
     addDockWidget(Qt::RightDockWidgetArea, de);
     slideEditorDE = de;
     connect(slideEditorDE, SIGNAL(visibilityChanged(bool)), mainWindow,
@@ -118,12 +127,6 @@ void VymView::updateColors()
     // TreeEditor, HeadingEditor and MapEditor
 
     QString s;
-    // Selection
-    /*
-    treeEditor->setStyleSheet(
-        "selection-background-color: " + brush.color().name(QColor::HexArgb) + ";" +
-        "background-color: " + mapEditor->getScene()->backgroundBrush().color().name());
-        */
 
     MapDesign *mapDesign = model->mapDesign();
 
@@ -157,7 +160,7 @@ void VymView::updateColors()
     treeEditor->setPalette(palette);
 
     // s += "QTreeView::branch {color: red; background: palette(base);}";
-    treeEditor->setStyleSheet(s);
+    treeEditor->setStyleSheet("QTreeView{" + s + "} QTreeView:focus{" + editorFocusInStyle + "}");
 }
 
 void VymView::changeSelection(const QItemSelection &newsel,
@@ -300,3 +303,4 @@ void VymView::setSlideEditorVisibility(bool b)
 }
 
 void VymView::setFocusMapEditor() { mapEditor->setFocus(); }
+void VymView::setFocusTreeEditor() { treeEditor->setFocus(); }
