@@ -1,12 +1,14 @@
 #ifndef XLINKITEM_H
 #define XLINKITEM_H
 
+#include "mapitem.h"
+
 class BranchItem;
 class QGraphicsScene;
+class XLink;
 class XLinkObj;
+class XLinkWrapper;
 
-#include "mapitem.h"
-#include "xlink.h"
 
 /*! \brief xlinks are used to draw arbitrary connections between branches
  * (BranchObj) in the map. */
@@ -17,19 +19,19 @@ class XLinkItem : public MapItem {
   public:
     enum XLinkState { undefinedXLink, initXLink, activeXLink, deleteXLink };
 
-    XLinkItem(TreeItem *parent = NULL);
+    XLinkItem(TreeItem *parent = nullptr);
     ~XLinkItem();
     void init();
-    void clear();
-    void setLink(Link *);
-    Link *getLink();
+    void setXLink(XLink *);
+    XLink* getXLink();
     void updateXLink();
-    MapObj *getMO();
-    void setSelection();
+    XLinkObj *getXLinkObj();
+    QColor headingColor();
+    void setSelectionType();
     BranchItem *getPartnerBranch();
 
   private:
-    Link *link;
+    XLink *xlinkInt;
 };
 
 #endif
