@@ -1,18 +1,21 @@
 #!/bin/bash
 
 SRCDIR=test
+OLDDIR=$(pwd)
+
 VYMTESTDIR=$(mktemp -d /tmp/vym-test-XXXX)
 
-DEFAULTMAP=$SRCDIR/default.vym
-TESTMAP=$VYMTESTDIR/testmap.vym
-
-cp $DEFAULTMAP $TESTMAP
+echo Created $VYMTESTDIR
 
 vym  -l -t -n test  -geometry 768x576-0+0 &
 
 PID=$!
 
-$SRCDIR/vym-test.rb -d $VYMTESTDIR $TESTMAP
+cd $SRCDIR
+
+vym-test.rb -d $VYMTESTDIR
 
 kill -s 15 $PID
 echo To clean up, do: rm -rf $VYMTESTDIR
+
+cd $OLDDIR
